@@ -21,23 +21,30 @@ try:
 except NameError:
     unicode = str
 
-__signature__ = 0x44d30904369891fbe9a995aec3c231da
+__signature__ = 0xe398cbb4fc069aeb5749ca4ffb9bd8fc
 
 
 def isdeviceavailable(supported_devices, device):
     """Checks if the divece is available."""
-    module_is_valid = False
+    if isinstance_of_magicmock(device, supported_devices):
+        return True
 
-    # for unittests 'MagicMock' should allways be supported
-    if type(device).__name__ == 'MagicMock':
-        module_is_valid = True
+    if isinstance(device, tuple(supported_devices)):
+        return True
 
-    for supported_device in supported_devices:
-        if supported_device:
-            if isinstance(device, supported_device):
-                module_is_valid = True
+    return False
 
-    return module_is_valid
+
+def isinstance_of_magicmock(device, objects):
+    """
+    Checks if the type 'object' is a MagicMock of 'object'
+    :return: boolen
+    """
+    for supported_object in objects:
+        if type(device).__name__ == 'MagicMock':
+            if type(device).__str__().find(str(supported_object).split('.')[-1].replace("'>", "")) >= 0:
+                return True
+    return False
 
 
 def gethexstr(paramids):
@@ -95,6 +102,14 @@ def getsupportedfunctions(qhlp, dostrip=True):
                     if item.endswith('?'):
                         item = 'q%s' % item[:-1]
                     funcs.append('MAC_%s' % item)
+        elif funcname == 'REC':
+            sub_methods = ['START', 'STOP', 'TRG', 'TRACE', 'RATE']
+            sub_methods = ["REC_{cmd}".format(cmd=cmd) for cmd in sub_methods]
+            funcs += sub_methods
+        elif funcname == 'qREC':
+            sub_methods = ['TRG', 'TRACE', 'RATE', 'DAT', 'STATE', 'NUM']
+            sub_methods = ["qREC_{cmd}".format(cmd=cmd) for cmd in sub_methods]
+            funcs += sub_methods
         else:
             funcs.append(funcnames.get(funcname, funcname))
     return funcs
@@ -522,6 +537,7 @@ def logsysinfo():
     pyver = '{0.major}.{0.minor}.{0.micro} {0.releaselevel}'.format(sys.version_info)
     debug('Python: %s %s', pyver, platform.architecture()[0])
 
+
 def getparamstringofnsinglearguments(*arguments):
     """
     Gets a GCS-Command-Parameter-String of N parameters
