@@ -11,7 +11,7 @@ import sys
 from .. import GCSError
 from .. interfaces.pigateway import PIGateway
 
-__signature__ = 0x35a6b2b11c95a1d082ce3967202df010
+__signature__ = 0x5331a832c47bb4c5e25eb1ef3a1efe13
 
 DLLDEVICES = {
     'C7XX_GCS_DLL': ['C-702', ],
@@ -687,3 +687,37 @@ class GCSDll(PIGateway):
         configs = configs.value.decode(encoding='cp1252', errors='ignore')
         debug('GCSDll.getconfigs(id%d): %r', self._id, configs)
         return configs
+
+    def GetDllVersionInformation(self):
+        """ Get the DLL version information
+        :return: Awnser as string
+        :rtype: string
+
+        """
+        debug('GCSDll.GetDllVersionInformation()')
+
+        bufsize = 100000
+        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        if getattr(self._handle, self._prefix + 'GetDllVersionInformation')(self._id, bufstr, bufsize) < 0:
+            raise GCSError(self._error)
+
+        answer = bufstr.value.decode(encoding='cp1252', errors='ignore')
+        debug('GCSDll.GetDllVersionInformation = %r', answer)
+        return answer
+
+    def GetPIStages3VersionInformation(self):
+        """ Get the DLL version information
+        :return: Awnser as string
+        :rtype: string
+
+        """
+        debug('GCSDll.GetPIStages3VersionInformation()')
+
+        bufsize = 100000
+        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        if getattr(self._handle, self._prefix + 'GetPIStages3VersionInformation')(self._id, bufstr, bufsize) < 0:
+            raise GCSError(self._error)
+
+        answer = bufstr.value.decode(encoding='cp1252', errors='ignore')
+        debug('GCSDll.GetPIStages3VersionInformation = %r', answer)
+        return answer
